==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebValuesChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebValuesChangeDetailDescriptionMetadata } from "./WebValuesChangeDetailDescriptionMetadata";
import { WebValuesChangeEventArgsDescription } from "./WebValuesChangeEventArgsDescription";
/**
 * @hidden
 */
var WebValuesChangeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebValuesChangeEventArgsDescriptionMetadata, _super);
    function WebValuesChangeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebValuesChangeEventArgsDescriptionMetadata.b = function (a) {
        if (WebValuesChangeEventArgsDescriptionMetadata.a == null) {
            WebValuesChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebValuesChangeEventArgsDescriptionMetadata.c(WebValuesChangeEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebValuesChangeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebValuesChangeEventArgsDescriptionMetadata.a);
        WebValuesChangeDetailDescriptionMetadata.d(a);
    };
    WebValuesChangeEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ValuesChangeEventArgs");
        a.item("Detail", "ExportedType:WebValuesChangeDetail");
    };
    WebValuesChangeEventArgsDescriptionMetadata.d = function (a) {
        WebValuesChangeEventArgsDescriptionMetadata.b(a);
        a.ad("WebValuesChangeEventArgs", function () { return new WebValuesChangeEventArgsDescription(); });
        a.ac("WebValuesChangeEventArgs", WebValuesChangeEventArgsDescriptionMetadata.a);
    };
    WebValuesChangeEventArgsDescriptionMetadata.$t = markType(WebValuesChangeEventArgsDescriptionMetadata, 'WebValuesChangeEventArgsDescriptionMetadata');
    WebValuesChangeEventArgsDescriptionMetadata.a = null;
    return WebValuesChangeEventArgsDescriptionMetadata;
}(Base));
export { WebValuesChangeEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebValuesChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebValuesChangeDetailDescriptionMetadata } from "./WebValuesChangeDetailDescriptionMetadata";
import { WebValuesChangeEventArgsDescription } from "./WebValuesChangeEventArgsDescription";
/**
 * @hidden
 */
var WebValuesChangeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebValuesChangeEventArgsDescriptionMetadata, _super);
    function WebValuesChangeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebValuesChangeEventArgsDescriptionMetadata.b = function (a) {
        if (WebValuesChangeEventArgsDescriptionMetadata.a == null) {
            WebValuesChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebValuesChangeEventArgsDescriptionMetadata.c(WebValuesChangeEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebValuesChangeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebValuesChangeEventArgsDescriptionMetadata.a);
        WebValuesChangeDetailDescriptionMetadata.d(a);
    };
    WebValuesChangeEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ValuesChangeEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("Detail", "ExportedType:WebValuesChangeDetail");
    };
    WebValuesChangeEventArgsDescriptionMetadata.d = function (a) {
        WebValuesChangeEventArgsDescriptionMetadata.b(a);
        a.ae("WebValuesChangeEventArgs", function () { return new WebValuesChangeEventArgsDescription(); });
        a.ad("WebValuesChangeEventArgs", WebValuesChangeEventArgsDescriptionMetadata.a);
    };
    WebValuesChangeEventArgsDescriptionMetadata.$t = markType(WebValuesChangeEventArgsDescriptionMetadata, 'WebValuesChangeEventArgsDescriptionMetadata');
    WebValuesChangeEventArgsDescriptionMetadata.a = null;
    return WebValuesChangeEventArgsDescriptionMetadata;
}(Base));
export { WebValuesChangeEventArgsDescriptionMetadata };
